ProxyAddress

Enum ProxyAddress 

#[non_exhaustive]
pub enum ProxyAddress { Inet(SocketAddr), Unix(Vec<u8>), }
An address from a Proxy Protocol header

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Inet(SocketAddr)

IPv4 or IPv6 socket address (IP + port)



Unix(Vec<u8>)

Unix domain socket path (up to 108 bytes per the v2 spec)

Implementations

Source

impl ProxyAddress

pub fn as_inet(&self) -> Option<SocketAddr>

If this is an Inet address, return the SocketAddr

pub fn as_unix(&self) -> Option<&[u8]>

If this is a Unix address, return the path bytes

pub fn ip(&self) -> Option<IpAddr>

If this is an Inet address, return just the IP